CLEANUP: connection: merge CO_FL_NOTIFY_DATA and CO_FL_NOTIFY_DONE

Both flags became equal in commit 82967bf9 ("MINOR: connection: adjust
CO_FL_NOTIFY_DATA after removal of flags"), which already predicted the
overlap between xprt_done_cb() and wake() after the removal of the DATA
specific flags in 1.8. Let's simply remove CO_FL_NOTIFY_DATA since the
"_DONE" version already covers everything and explains the intent well
enough.
diff --git a/src/connection.c b/src/connection.c
index 82890f9..3337538 100644
--- a/src/connection.c
+++ b/src/connection.c
@@ -126,8 +126,8 @@
 	 * data layer activity (successful send/recv), connection establishment,
 	 * shutdown and fatal errors. We need to consider the following
 	 * situations to wake up the data layer :
 	 *  - change among the CO_FL_NOTIFY_DATA flags :
 	 *      {DATA,SOCK}_{RD,WR}_SH, ERROR,
 	 *  - absence of any of {L4,L6}_CONN and CONNECTED, indicating the
 	 *    end of handshake and transition to CONNECTED
 	 *  - raise of CONNECTED with HANDSHAKE down
@@ -137,7 +137,7 @@
 	 * Note that the wake callback is allowed to release the connection and
 	 * the fd (and return < 0 in this case).
 	 */
-	if ((io_available || (((conn->flags ^ flags) & CO_FL_NOTIFY_DATA) ||
+	if ((io_available || (((conn->flags ^ flags) & CO_FL_NOTIFY_DONE) ||
 	     ((flags & (CO_FL_CONNECTED|CO_FL_HANDSHAKE)) != CO_FL_CONNECTED &&
 	      (conn->flags & (CO_FL_CONNECTED|CO_FL_HANDSHAKE)) == CO_FL_CONNECTED))) &&
 	    conn->mux && conn->mux->wake && conn->mux->wake(conn) < 0)
@@ -126,8 +126,8 @@
 	 * shutdown and fatal errors. We need to consider the following
 	 * situations to wake up the data layer :
-	 *  - change among the CO_FL_NOTIFY_DATA flags :
-	 *      {DATA,SOCK}_{RD,WR}_SH, ERROR,
+	 *  - change among the CO_FL_NOTIFY_DONE flags :
+	 *      SOCK_{RD,WR}_SH, ERROR,
 	 *  - absence of any of {L4,L6}_CONN and CONNECTED, indicating the
 	 *    end of handshake and transition to CONNECTED